cbuilder Package
================

:mod:`cbuilder` Package
-----------------------

.. automodule:: numba.utility.cbuilder
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`library` Module
---------------------

.. automodule:: numba.utility.cbuilder.library
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`numbacdef` Module
-----------------------

.. automodule:: numba.utility.cbuilder.numbacdef
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`refcounting` Module
-------------------------

.. automodule:: numba.utility.cbuilder.refcounting
    :members:
    :undoc-members:
    :show-inheritance:

